* Stop syntax and large titles from printing to output.
SET PRINTBACK=NONE HEADER=NO.

***********************************************************************************.
*******            BEGIN DATA MANIPULATION FOR CHAPTER 2 EXAMPLE            *******.
*******                CHANGE "filesave" to your directory                  *******.
***********************************************************************************.

* Define location of files used in code below.
FILE HANDLE filesave /NAME = "C:\Dropbox\14_SPLH861\861_Example1".
* Import chapter 2 example data.
GET FILE = "filesave/SPSS_Chapter2.sav".
DATASET NAME Chapter2 WINDOW=FRONT.
* Center continuous predictors.
COMPUTE age85 = age - 85.
COMPUTE grip9 = grip - 9.
* Re-coding sex so women are reference (unnecessary).
IF (sexMW=0) sexwm=1. 
IF (sexMW=1) sexwm=0.
* Creating contrasts for dementia groups.
DO IF (demgroup=1).
COMPUTE demNF=0.
COMPUTE demNC=0.
END IF.
DO IF (demgroup=2).
COMPUTE demNF=1.
COMPUTE demNC=0.
END IF.
DO IF (demgroup=3).
COMPUTE demNF=0.
COMPUTE demNC=1.
END IF.
* Labeling new variables.
VARIABLE LABELS
age85  "age85: Age in Years (0=85)"
grip9  "grip9: Grip Strength in Pounds (0=9)"
sexwm  "sexwm: Sex (0=Women, 1=Men)"
demNF  "demNF: Dementia Contrast for None=0 vs Future=1"
demNC  "demNC: Dementia Contrast for None=0 vs Current=1".
EXECUTE.

***********************************************************************************.
*******                       BEGIN EXAMPLE 1 MODELS                        *******.
***********************************************************************************.

* Open output directory.
OUTPUT NAME SPSS_Example1_Output.

ECHO "Chapter 2: Descriptive Statistics for Example Variables".
DESCRIPTIVES VARIABLES= age grip cognition.
CROSSTABS TABLES= sexMW BY demgroup.
CORRELATIONS VARIABLES age grip sexMW cognition.

DATASET ACTIVATE Chapter2 WINDOW=FRONT.
ECHO 'Eq 2.3: Empty Means Model'.
MIXED cognition
     /METHOD   = REML
     /PRINT    = SOLUTION TESTCOV 
     /FIXED    = .
 
DATASET ACTIVATE Chapter2 WINDOW=FRONT.
ECHO 'Eq 2.4: Adding Age 0=85'.
MIXED cognition WITH age85
     /METHOD   = REML
     /PRINT    = SOLUTION TESTCOV 
     /FIXED    = age85
     /SAVE     = FIXPRED (PredAge).
CORRELATIONS cognition PredAge.

DATASET ACTIVATE Chapter2 WINDOW=FRONT.
ECHO 'Eq 2.6: Adding Grip 0=9'.
MIXED cognition WITH age85 grip9
     /METHOD   = REML
     /PRINT    = SOLUTION TESTCOV 
     /FIXED    = age85 grip9
     /TEST     = "Model R2 Test" age85 1; grip9 1.

DATASET ACTIVATE Chapter2 WINDOW=FRONT.
ECHO 'Eq 2.7: Adding Sex 0=M 1=W'.
MIXED cognition WITH age85 grip9 sexMW
     /METHOD   = REML
     /PRINT    = SOLUTION TESTCOV 
     /FIXED    = age85 grip9 sexMW
     /TEST     = "Intercept for Women" intercept 1 sexMW 1
     /TEST     = "Model R2 Test" age85 1; grip9 1; sexMW 1.

DATASET ACTIVATE Chapter2 WINDOW=FRONT.
ECHO 'Eq 2.8: Adding Dementia Group'
      + ', Using Manual Group Contrasts so Reference=None'.
MIXED cognition WITH age85 grip9 sexMW demNF demNC
     /METHOD   = REML
     /PRINT    = SOLUTION TESTCOV 
     /FIXED    = age85 grip9 sexMW demNF demNC
     /TEST     = "Model R2 F-Test" age85 1; grip9 1; sexMW 1; demNF 1; demNC 1
     /TEST     = "Omnibus F-Test for Dementia Group" demNF 1; demNC 1
     /TEST     = "Intercept for None Group"      intercept 1 demNF 0 demNC 0
     /TEST     = "Intercept for Future Group"    intercept 1 demNF 1 demNC 0
     /TEST     = "Intercept for Current Group"   intercept 1 demNF 0 demNC 1
     /TEST     = "None   vs Future  Group"       demNF  1 demNC 0
     /TEST     = "None   vs Current Group"       demNF  0 demNC 1
     /TEST     = "Future vs Current Group"       demNF -1 demNC 1.

* Close and export output directory.
OUTPUT EXPORT
  /CONTENTS  EXPORT=VISIBLE  LAYERS=VISIBLE  MODELVIEWS=VISIBLE
  /DOC  DOCUMENTFILE="filesave\SPSS_Example1_Output.doc"
     NOTESCAPTIONS=YES  WIDETABLES=WRAP PAGEBREAKS=YES
     PAGESIZE=INCHES(8.5, 11.0)  TOPMARGIN=INCHES(1.0)  BOTTOMMARGIN=INCHES(1.0)
     LEFTMARGIN=INCHES(1.0)  RIGHTMARGIN=INCHES(1.0).